%define anolis_release 2

%bcond_without inotify
%bcond_without audit
%bcond_without pam
%bcond_without selinux

Summary:   Cron daemon for executing programs at set times
Name:      cronie
Version:   1.6.1
Release:   %{anolis_release}%{?dist}
License:   MIT and BSD and ISC and GPLv2+
URL:       https://github.com/%{name}-crond/%{name}
Source0:   https://github.com/%{name}-crond/%{name}/releases/download/%{name}-%{version}/%{name}-%{version}.tar.gz

%if %{with audit}
Buildrequires: audit-libs-devel >= 1.4.1
%endif
%if %{with pam}
Buildrequires: pam-devel >= 1.0.1
Requires:      pam >= 1.0.1
%endif
%if %{with selinux}
Buildrequires: libselinux-devel >= 2.0.64
Requires:      libselinux >= 2.0.64
%endif

BuildRequires:    gcc systemd make
Requires:  dailyjobs
Obsoletes:        %{name}-sysvinit
Requires(post):   coreutils sed

%{?systemd_ordering}

%description

Cronie is a daemon that runs specified programs at scheduled times and related 
tools. It is a fork of the original vixie-cron that has been enhanced with 
security and configuration features such as the ability to use pam and SELinux. 
Cronie is a reliable and efficient tool that can help automate tasks and 
improve system performance by scheduling tasks to run at specific times or 
intervals. It is widely used in UNIX-based systems for various purposes such 
as system maintenance, backups, and data processing.

%package anacron
Summary:   Utility for running regular jobs
Requires:  crontabs
Provides:  dailyjobs anacron = 2.4 %{name} = %{version}-%{release}
Obsoletes: anacron <= 2.3
Requires(post): coreutils

%description anacron
Anacron is a tool that is part of %{name} and is used for running jobs with 
regular periodicity that do not have an exact time of day of execution. 

The default settings of anacron execute daily, weekly, and monthly jobs, but it 
allows setting arbitrary periodicity of jobs as well. 

Anacron is a useful tool that allows running periodic jobs even if the system 
is often powered off and it also allows randomizing the time of job execution 
for better utilization of resources shared among multiple systems. It can be 
used for various purposes such as system maintenance, backups, and data 
processing in UNIX-based systems.

%package noanacron
Summary:   Old style utility for running simple regular jobs
Provides:  dailyjobs
Requires:  crontabs %{name} = %{version}-%{release}

%description noanacron

This package provides a legacy tool of running hourly, daily, weekly or monthly
jobs. It runs without anacron, but won’t provide any extra features.

%package doc
Summary:   Documentation files for %{name}
Requires:  %{name} = %{version}-%{release}
BuildArch: noarch

%description doc
The %{name}-doc package contains documentation files.

%prep
%autosetup -p1

%build
%configure \
--enable-anacron \
--enable-pie \
--enable-relro \
%if %{with inotify}
--with-inotify \
%endif
%if %{with audit}
--with-audit \
%endif
%if %{with selinux}
--with-selinux \
%endif
%if %{with pam}
--with-pam
%endif

%make_build V=2

%install
%make_install DESTMAN=$RPM_BUILD_ROOT%{_mandir}
mkdir -pm755 $RPM_BUILD_ROOT%{_sysconfdir}/cron.d/
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/
mkdir -pm700 $RPM_BUILD_ROOT%{_localstatedir}/spool/cron

mkdir -pm 755 $RPM_BUILD_ROOT%{_sysconfdir}/cron.hourly
install -c -m755 contrib/0anacron $RPM_BUILD_ROOT%{_sysconfdir}/cron.hourly/0anacron
install -m 644 crond.sysconfig $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/crond
touch $RPM_BUILD_ROOT%{_sysconfdir}/cron.deny
install -m 644 contrib/anacrontab $RPM_BUILD_ROOT%{_sysconfdir}/anacrontab
install -c -m755 contrib/0hourly $RPM_BUILD_ROOT%{_sysconfdir}/cron.d/0hourly
mkdir -p $RPM_BUILD_ROOT/var/spool/anacron

for f in cron.daily cron.weekly cron.monthly; do
    touch $RPM_BUILD_ROOT/var/spool/anacron/$f
done
mkdir -p $RPM_BUILD_ROOT/lib/systemd/system/
install -m 644 contrib/%{name}.systemd $RPM_BUILD_ROOT/lib/systemd/system/crond.service
install -m 644 contrib/dailyjobs $RPM_BUILD_ROOT/%{_sysconfdir}/cron.d/dailyjobs
%if ! %{with pam}
    rm -f $RPM_BUILD_ROOT%{_sysconfdir}/pam.d/crond
%endif

%post
%systemd_post crond.service

%post anacron
for f in cron.daily cron.weekly cron.monthly; do
    [ -e /var/spool/anacron/$f ] || touch /var/spool/anacron/$f 2>/dev/null || :
done

%preun
%systemd_preun crond.service

%postun
%systemd_postun_with_restart crond.service

%triggerun -- %{name}-anacron < 1.4.1
cp -a /etc/crontab /etc/crontab.rpmsave
sed -e '/^01 \* \* \* \* root run-parts \/etc\/cron\.hourly/d'\
    -e '/^02 4 \* \* \* root run-parts \/etc\/cron\.daily/d'\ 
    -e '/^22 4 \* \* 0 root run-parts \/etc\/cron\.weekly/d'\
    -e '/^42 4 1 \* \* root run-parts \/etc\/cron\.monthly/d' /etc/crontab.rpmsave > /etc/crontab
exit 0

%triggerun -- %{name} < 1.4.7-2
/usr/bin/systemd-sysv-convert --save crond

/bin/systemctl enable crond.service >/dev/null 2>&1

/sbin/chkconfig --del crond >/dev/null 2>&1 || :
/bin/systemctl try-restart crond.service >/dev/null 2>&1 || :
/bin/systemctl daemon-reload >/dev/null 2>&1 || :

%triggerin -- pam, glibc, libselinux
/bin/systemctl try-restart crond.service >/dev/null 2>&1 || :

%files
%{!?_licensedir:%global license %%doc}
%license COPYING
%attr(755,root,root) %{_sbindir}/crond
%attr(4755,root,root) %{_bindir}/crontab
%attr(755,root,root) %{_bindir}/cronnext
%{_mandir}/*/cron*
%dir %{_localstatedir}/spool/cron
%dir %{_sysconfdir}/cron.d
%if %{with pam}
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/pam.d/crond
%endif
%attr(0644,root,root) /lib/systemd/system/crond.service
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/cron.d/0hourly
%config(noreplace) %{_sysconfdir}/cron.deny
%config(noreplace) %{_sysconfdir}/sysconfig/crond

%files anacron
%dir /var/spool/anacron
%{_mandir}/*/anacron*
%ghost %attr(0600,root,root) %verify(not md5 size mtime) /var/spool/anacron/cron.*
%{_sbindir}/anacron
%config(noreplace) %{_sysconfdir}/anacrontab
%attr(0755,root,root) %{_sysconfdir}/cron.hourly/0anacron

%files noanacron
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/cron.d/dailyjobs

%files doc
%doc AUTHORS README ChangeLog

%changelog
* Tue Apr 11 2023 Zhongling <zhonglingh@linux.alibaba.com> - 1.6.1-2
- Refactor rpm spec

* Fri Oct 21 2022 Kaihao Bai <carlo.bai@linux.alibaba.com> - 1.6.1-1
- update to 1.6.1

* Wed Mar 09 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1.5.7-1
- init from usptream 1.5.7
